﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using System.IO;
using System.Runtime.InteropServices;

// Useful URLs:
//      Unblock files (used in this example):
//      https://stackoverflow.com/questions/6374673/unblock-file-from-within-net-4-c-sharp
//
//      See which files are from different zones:
//      https://social.msdn.microsoft.com/Forums/azure/en-US/aadc5e86-1b6e-4ae4-a5dc-3c053cca93f0/c-how-to-check-if-a-file-is-blocked?forum=csharpgeneral

namespace howto_unblock_files
{
    public partial class Form1 : Form
    {
        [DllImport("kernel32", CharSet = CharSet.Unicode, SetLastError = true)]
        [return: MarshalAs(UnmanagedType.Bool)]
        private static extern bool DeleteFile(string name);

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            ofdFiles.Multiselect = true;
            clbFiles.CheckOnClick = true;
        }

        // Let the user select some files.
        private void mnuFileOpen_Click(object sender, EventArgs e)
        {
            if (ofdFiles.ShowDialog() == DialogResult.OK)
            {
                // Add the selected files to the lists.
                clbFiles.Items.Clear();
                foreach (string filename in ofdFiles.FileNames)
                {
                    FileNameInfo name_info = new FileNameInfo(filename);
                    int index = clbFiles.Items.Add(name_info);
                }

                // Check all of the files.
                clbFiles.CheckAll();
            }
        }

        // Unblock the files.
        private void btnUnblock_Click(object sender, EventArgs e)
        {
            Cursor = Cursors.WaitCursor;

            int num_unblocked = 0;
            foreach (FileNameInfo name_info in clbFiles.CheckedItems)
            {
                string filename = name_info.FullName;
                if (UnblockFile(filename)) num_unblocked++;
            }

            // Uncheck all of the files.
            clbFiles.UncheckAll();
            Cursor = Cursors.Default;

            MessageBox.Show(string.Format("Unblocked {0} files.", num_unblocked));
        }

        // Unblock the file and return true if successful.
        // This method seems to return false if there is
        // a problem rather than throwing an exception.
        public bool UnblockFile(string fileName)
        {
            return DeleteFile(fileName + ":Zone.Identifier");
        }
    }
}
